#ifndef NT2_INCLUDE_CONSTANTS_GOLD_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_GOLD_HPP_INCLUDED

#include <nt2/constant/include/constants/gold.hpp>

#endif
